@@ -1,5 +1,10 @@
-#import psyco
-#psyco.full()
+import rel
+rel.override()
+try:
+    import psyco
+    psyco.full()
+except ImportError:
+    pass
 import sys
 import os
 #sys.path.insert(0, os.path.abspath('.'))
@@ -8,10 +13,10 @@ from orbited.app import Application
 from orbited import transport
 from orbited import plugin
 from orbited.http import router
-
 server = None
 
 def main():
+    print rel
     load()
     do_start()
 
